==> zio-aws-macie2_2.12-5.20.22.1-sources.jar: zio/aws/macie2/model/UpdateAllowListResponse.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.{
  __stringMin22Max22PatternAZ0922,
  __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UpdateAllowListResponse(
    arn: Optional[
      __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
    ] = Optional.Absent,
    id: Optional[__stringMin22Max22PatternAZ0922] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.UpdateAllowListResponse = {
    import UpdateAllowListResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.UpdateAllowListResponse
      .builder()
      .optionallyWith(arn.map(value => value: java.lang.String))(_.arn)
      .optionallyWith(id.map(value => value: java.lang.String))(_.id)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.UpdateAllowListResponse.ReadOnly =
    zio.aws.macie2.model.UpdateAllowListResponse.wrap(buildAwsValue())
}
object UpdateAllowListResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.UpdateAllowListResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.UpdateAllowListResponse =
      zio.aws.macie2.model.UpdateAllowListResponse(
        arn.map(value => value),
        id.map(value => value)
      )
    def arn: Optional[
      __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
    ]
    def id: Optional[__stringMin22Max22PatternAZ0922]
    def getArn: ZIO[
      Any,
      AwsError,
      __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
    ] = AwsError.unwrapOptionField("arn", arn)
    def getId: ZIO[Any, AwsError, __stringMin22Max22PatternAZ0922] =
      AwsError.unwrapOptionField("id", id)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.UpdateAllowListResponse
  ) extends zio.aws.macie2.model.UpdateAllowListResponse.ReadOnly {
    override val arn: Optional[
      __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.arn())
      .map(value =>
        value: __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
      )
    override val id: Optional[__stringMin22Max22PatternAZ0922] =
      zio.aws.core.internal
        .optionalFromNullable(impl.id())
        .map(value => value: __stringMin22Max22PatternAZ0922)
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.UpdateAllowListResponse
  ): zio.aws.macie2.model.UpdateAllowListResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-macie2_3-5.19.7.3-sources.jar: zio/aws/macie2/model/UpdateAllowListResponse.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.{
  __stringMin22Max22PatternAZ0922,
  __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class UpdateAllowListResponse(
    arn: Optional[
      __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
    ] = Optional.Absent,
    id: Optional[__stringMin22Max22PatternAZ0922] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.UpdateAllowListResponse = {
    import UpdateAllowListResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.UpdateAllowListResponse
      .builder()
      .optionallyWith(arn.map(value => value: java.lang.String))(_.arn)
      .optionallyWith(id.map(value => value: java.lang.String))(_.id)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.UpdateAllowListResponse.ReadOnly =
    zio.aws.macie2.model.UpdateAllowListResponse.wrap(buildAwsValue())
}
object UpdateAllowListResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.UpdateAllowListResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.UpdateAllowListResponse =
      zio.aws.macie2.model.UpdateAllowListResponse(
        arn.map(value => value),
        id.map(value => value)
      )
    def arn: Optional[
      __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
    ]
    def id: Optional[__stringMin22Max22PatternAZ0922]
    def getArn: ZIO[
      Any,
      AwsError,
      __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
    ] = AwsError.unwrapOptionField("arn", arn)
    def getId: ZIO[Any, AwsError, __stringMin22Max22PatternAZ0922] =
      AwsError.unwrapOptionField("id", id)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.UpdateAllowListResponse
  ) extends zio.aws.macie2.model.UpdateAllowListResponse.ReadOnly {
    override val arn: Optional[
      __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.arn())
      .map(value =>
        value: __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
      )
    override val id: Optional[__stringMin22Max22PatternAZ0922] =
      zio.aws.core.internal
        .optionalFromNullable(impl.id())
        .map(value => value: __stringMin22Max22PatternAZ0922)
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.UpdateAllowListResponse
  ): zio.aws.macie2.model.UpdateAllowListResponse.ReadOnly = new Wrapper(impl)
}
